library multi_image_view;

import 'dart:io';

import 'package:flutter/material.dart';
import 'package:multi_image_view/models/ImageModel.dart';
import 'package:multi_image_view/providers/image_picker_provider.dart';
import 'package:multi_image_view/theme/colors.dart';
import 'package:provider/provider.dart';

class MultiImageView extends StatefulWidget {
  final MultiImageContoller? contoller;
  final Function(ImageModel)? onImageSelect;
  final double? itemSpacing;
  const MultiImageView({Key? key,  this.contoller,this.onImageSelect,this.itemSpacing}) : super(key: key);

  @override
  _MultiImageViewState createState() => _MultiImageViewState();
}

class _MultiImageViewState extends State<MultiImageView> {


  @override
  Widget build(BuildContext context) {
    return MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (context) => widget.contoller??MultiImageContoller())
        ],
        builder: (context, snapshot) {
          return Consumer<MultiImageContoller>(
            builder: (context, provider, child) {
              return ListView.builder(
                  itemCount: provider.imageList.length + 1,
                  scrollDirection: Axis.horizontal,
                  itemBuilder: (context, index) => Padding(
                        padding: EdgeInsets.all(widget.itemSpacing??8.0),
                        child: index == provider.imageList.length
                            ? buildAddButton(
                            onTap:()async{
                              var imageModel=await provider.pickImage();
                              widget.onImageSelect!(imageModel!);
                        })
                            : buildImageView(
                                provider.imageList[index].imageFile!,
                          onDelete: ()=>provider.delete(index),
                          onTap: (file)=>provider.showFullImage(file, context)
                        ),
                      ));
            },
          );
        });
  }
}

Widget buildImageView(File file,{Function? onTap,Function? onDelete}) {
  return Stack(

    children: [
      Padding(
        padding: const EdgeInsets.all(6.0),
        child: InkWell(
          onTap: ()=>onTap!(file),
          child: AspectRatio(
            aspectRatio: 1 / 1,
            child: Container(
              padding: const EdgeInsets.all(4),
              decoration: BoxDecoration(
                  color: const Color(0xffDFDFDE),
                  borderRadius: BorderRadius.circular(5)),
              width: 100,
              height: 100,
              child: Image.file(
                file,
                fit: BoxFit.cover,
              ),
            ),
          ),
        ),
      ),
      Positioned(
        top: -14,
          right: -14,
          child: IconButton(
            color: Colors.red,

              onPressed: (){
            onDelete!();
          }, icon: const Icon(Icons.cancel_sharp,color: Colors.red,)))
    ],
  );
}

Widget buildAddButton({Function? onTap}) {
  return Padding(
    padding: const EdgeInsets.all(6.0),
    child: InkWell(
      onTap:()=>onTap!(),
      child: AspectRatio(
        aspectRatio: 1 / 1,
        child: Container(
          padding: const EdgeInsets.all(5),
          decoration: BoxDecoration(
              color: lightWhiteColor,
              borderRadius: BorderRadius.circular(5)),
          width: 100,
          height: 100,
          child: const Icon(Icons.add),
        ),
      ),
    ),
  );
}
